summaryrefslogtreecommitdiffstats
path: root/include/view.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/view.h')
-rw-r--r--include/view.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/view.h b/include/view.h
index 82f52f3c..64bc1d1a 100644
--- a/include/view.h
+++ b/include/view.h
@@ -60,14 +60,14 @@ typedef enum
/**
* @param sw the Mode to show.
* @param input A pointer to a string where the inputted data is placed.
* @param flags Flags indicating state of the menu.
* @param finalize the finailze callback
*
* Main menu callback.
*
* @returns The command issued (see MenuReturn)
*/
-RofiViewState *rofi_view_create ( Mode *sw, const char *input, MenuFlags flags, void ( *finalize )( RofiViewState * ) );
+RofiViewState *rofi_view_create ( Mode *sw, const char *input, MenuFlags menu_flags, void ( *finalize )( RofiViewState * ) );
/**
* @param state The Menu Handle
@@ -60,14 +60,14 @@ typedef enum
* @param sw the Mode to show.
* @param input A pointer to a string where the inputted data is placed.
- * @param flags Flags indicating state of the menu.
+ * @param menu_flags Flags indicating state of the menu.
* @param finalize the finailze callback
*